qr_code_dart_decoder library

Classes

CameraDecode
CropBackgroundProcessor
CropBackgroundYuv
CropBackgroundYuvProcessor
CropCenterSquare
CroppingStrategy
CropRect
An immutable, 2D, axis-aligned, floating-point rectangle whose coordinates are relative to a given origin.
CropReductionMinorAxis
CropVect
CropYuv
FileDecode
FileDecodeEvent
Created by
ImagePreProcessor
IsolateCameraDecode
controller an isolate to executer decode command
QrCodeDartDecoder
A Calculator.
Result
Encapsulates the result of decoding a barcode within an image.
Yuv420Planes
YuvPreProcessor

Enums

BarcodeFormat
Enumerates barcode formats known to this package.
RotationType